@@ -2,7 +2,7 @@ use shell_rs::mkdir;
 
 fn main() {
     let options = mkdir::Options {
-        recursive: true,
+        parents: true,
         mode: 0o777,
         ..Default::default()
     };
