@@ -5,6 +5,8 @@
 pub mod arch;
 pub mod env;
 pub mod fs;
+pub mod getlogin;
 pub mod grp;
+pub mod misc;
 pub mod pwd;
 pub mod str;
