@@ -10,8 +10,10 @@ pub mod error;
 pub mod groups;
 pub mod hashsum;
 pub mod head;
+pub mod hostname;
 pub mod id;
 pub mod ln;
+pub mod logname;
 pub mod ls;
 pub mod mkdir;
 pub mod mv;
@@ -26,4 +28,5 @@ pub mod truncate;
 pub mod uname;
 pub mod unlink;
 pub mod uptime;
+pub mod which;
 pub mod whoami;
