@@ -6,7 +6,7 @@ use std::ffi::OsStr;
 use std::os::unix::ffi::OsStrExt;
 use std::path::PathBuf;
 
-use crate::error::{Error, ErrorKind};
+use crate::error::Error;
 
 #[derive(Debug, Clone, Copy, PartialEq)]
 pub enum Mode {
