@@ -7,7 +7,7 @@ use nc::Errno;
 use std::path::PathBuf;
 use std::result::Result;
 
-use crate::core::expand_env::expand_env;
+use crate::core::env::expand_env;
 
 pub struct RmOptions {
     /// Remove directories and their contenst recursively.
